@@ -13,7 +13,8 @@ import requests
 
 
 def gen_ru_words(check: int):
-    russian_nouns_txt = requests.get('https://raw.githubusercontent.com/Superior-GitHub/Superior6564/main/Txts/russian_nouns.txt')
+    russian_nouns_txt = requests.get('https://raw.githubusercontent.com/Superior-GitHub/Superior6564/main/superior6564/russian_nouns.txt')
+
     out_1 = open("russian_nouns.txt", "wb")
     out_1.write(russian_nouns_txt.content)
     out_1.close()
